[openib-general] [PATCH][SDP][13/22] Remove use of leading underscores in static names in sdp_post.c

Tom Duffy Tom.Duffy at Sun.COM
Mon Feb 28 14:02:12 PST 2005


Signed-off-by: Tom Duffy <tduffy at sun.com>

Index: drivers/infiniband/ulp/sdp/sdp_post.c
===================================================================
--- drivers/infiniband/ulp/sdp/sdp_post.c	(revision 1929)
+++ drivers/infiniband/ulp/sdp/sdp_post.c	(working copy)
@@ -85,9 +85,9 @@ int sdp_cm_listen_stop(struct sdev_root 
 }
 
 /*
  * _sdp_cm_disconnect - initiate a disconnect request using the CM
  */
-static void _sdp_cm_disconnect(void *arg)
+static void do_cm_disconnect(void *arg)
 {
 	struct sdp_opt *conn = (struct sdp_opt *)arg;
 	int result;
@@ -109,9 +109,9 @@ static void _sdp_cm_disconnect(void *arg
 }
 
 /*
  * _sdp_cm_reject - initiate a reject request using the CM
  */
-static void _sdp_cm_reject(void *arg)
+static void do_cm_reject(void *arg)
 {
 	struct sdp_opt *conn = (struct sdp_opt *)arg;
 	int result;
@@ -132,10 +132,10 @@ static void _sdp_cm_reject(void *arg)
 	sdp_conn_put(conn);
 }
 /*
- * _sdp_cm_deferred_generic - initiate a defered request using the CM
+ * sdp_cm_deferred_generic - initiate a defered request using the CM
  */
-static int _sdp_cm_deferred_generic(struct sdp_opt *conn,
-				    void (*defer_func)(void *arg))
+static int sdp_cm_deferred_generic(struct sdp_opt *conn,
+				   void (*defer_func)(void *arg))
 {
 	/*
 	 * send a potentially defered failed request.
@@ -156,7 +156,7 @@ static int _sdp_cm_deferred_generic(stru
 */
 int sdp_cm_disconnect(struct sdp_opt *conn)
 {
-	return _sdp_cm_deferred_generic(conn, _sdp_cm_disconnect);
+	return sdp_cm_deferred_generic(conn, do_cm_disconnect);
 }
 
 /*
@@ -164,5 +164,5 @@ int sdp_cm_disconnect(struct sdp_opt *co
  */
 int sdp_cm_reject(struct sdp_opt *conn)
 {
-	return _sdp_cm_deferred_generic(conn, _sdp_cm_reject);
+	return sdp_cm_deferred_generic(conn, do_cm_reject);
 }
@@ -85,9 +85,9 @@ int sdp_cm_listen_stop(struct sdev_root 
 
 /*
- * _sdp_cm_disconnect - initiate a disconnect request using the CM
+ * do_cm_disconnect - initiate a disconnect request using the CM
  */
@@ -109,9 +109,9 @@ static void _sdp_cm_disconnect(void *arg
 
 /*
- * _sdp_cm_reject - initiate a reject request using the CM
+ * do_cm_reject - initiate a reject request using the CM
  */




More information about the general mailing list